KeGen it's an easy to use library that creates key 

_____________________________________________________________________________________
Installation
install it via the pip install command
"pip install kegen"
_____________________________________________________________________________________
Usage:
You need to import Kegen in your file with " import KeGen " and " from KeGen import *"
 
Then you use it  with "KeGen.generate(-lengh of the key-)" or one of the following commands:

.generateletters(-lengh of the key-)  to generate  a key with only letters

.generatenumber(-lengh of the key-) to generate a key with only numbers

.generatekey(-lengh of the key-) to generate a key with letters and numbers

.write_to_file(filename , key) to write the key in a file

______________________________________________________________________________________
Contact 
author: Mario Sperandio Marato

email: s.mario12112009@gmail.com

git: https://github.com/M-suri
